@@ -1773,6 +1773,7 @@ class BirthdateField(DateField):
             """
         )
 
+
 class CheckboxesField(Field):
     """Checkboxes field.
 
@@ -2238,6 +2239,14 @@ class ChosenSelectField(PulldownField):
         zoom.requires('chosen')
 
 
+class TimezoneField(ChosenSelectField):
+
+    @property
+    def options(self):
+        import pytz
+        return pytz.all_timezones
+
+
 class MultiselectField(TextField):
     """Multiselect Field
 
