@@ -428,7 +428,7 @@ class EntityStore(Store):
 
     def _delete(self, ids):
         if ids:
-            affected = self.get(ids)
+            affected = list(self.get(ids))
 
             for rec in affected:
                 self.before_delete(rec)
