@@ -112,7 +112,6 @@ def get_groups(db, user):
     >>> 'administrators' in groups
     True
     """
-    logger = logging.getLogger(__name__)
 
     def get_memberships(group, memberships, depth=0):
         """get group memberships"""
@@ -138,14 +137,10 @@ def get_groups(db, user):
         'SELECT group_id, subgroup_id FROM subgroups ORDER BY subgroup_id'
     ))
 
-    # memberships = []
     groups = set()
     for group in my_groups:
-        # memberships += get_memberships(group, subgroups)
         groups |= get_memberships(group, subgroups)
 
-    # groups = my_groups + memberships
-
     named_groups = sorted(all_groups[g] for g in set(groups))
 
     return named_groups
@@ -516,6 +511,50 @@ class Users(RecordStore):
             key='id'
             )
 
+    def add(
+            self,
+            username,
+            first_name,
+            last_name,
+            email,
+            phone='',
+        ):
+        """Add user record to the database"""
+
+        def validate(value, validator):
+            """validate a value"""
+            if not validator(value):
+                raise Exception(validator.msg)
+
+        def username_not_taken(username):
+            return self.first(username=username) is None
+
+        v = zoom.validators
+        username_available = v.Validator('username taken', username_not_taken)
+        rules = (
+            (username, v.valid_username),
+            (first_name, v.valid_name),
+            (last_name, v.valid_name),
+            (email, v.valid_email),
+            (phone, v.valid_phone),
+            (username, username_available),
+        )
+
+        for value, rule in rules:
+            validate(value, rule)
+
+        user = User(
+            username=username,
+            first_name=first_name,
+            last_name=last_name,
+            email=email,
+            phone=phone,
+        )
+
+        self.put(user)
+
+        return user
+
     def before_insert(self, user):
         """Things to do just before inserting a new User record"""
         user.update(status='A')
@@ -525,16 +564,23 @@ class Users(RecordStore):
         """Things to do just before updating a User record"""
         user.updated = zoom.tools.now()
 
+    def after_update(self, user):
+        """Things to do immediately after a user update"""
+        audit('update user', user.username)
+
     def after_insert(self, user):
-        """Things to do right after inserting a new user"""
+        """Things to do immediately after inserting a new user"""
         user.remove_groups()  # avoid accidental authourizations
         user.add_group('users')
+        audit('create user', user.username)
 
     def before_delete(self, user):
-        """Things to do right before deleting a user"""
+        """Things to do immediately before deleting a user"""
         user.remove_groups()
+        audit('delete user', user.username)
 
     def locate(self, key):
+        """Locate a user by username or user_id"""
         user = key and (
             self.first(username=key) or
             self.first(username=key.replace('-', '\\')) or
